#[repr(i32)]pub enum FileFormatKind {
Unspecified = 0,
Csv = 1,
Json = 2,
Parquet = 3,
Arrow = 4,
Avro = 5,
}Expand description
Identifies a built-in file format supported by DataFusion. Used by DefaultLogicalExtensionCodec to serialize/deserialize FileFormatFactory instances (e.g. in CopyTo plans).
Variants
Implementations
Sourceimpl FileFormatKind
impl FileFormatKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.