pub struct FileSinkConfig {
pub object_store_url: String,
pub file_groups: Vec<PartitionedFile>,
pub table_paths: Vec<String>,
pub output_schema: Option<Schema>,
pub table_partition_cols: Vec<PartitionColumn>,
pub keep_partition_by_columns: bool,
pub insert_op: i32,
pub file_extension: String,
pub file_output_mode: i32,
}Fields
object_store_url: Stringfile_groups: Vec<PartitionedFile>table_paths: Vec<String>output_schema: Option<Schema>table_partition_cols: Vec<PartitionColumn>keep_partition_by_columns: boolinsert_op: i32file_extension: Stringfile_output_mode: i32Determines how the output path is interpreted.
Implementations
Sourceimpl FileSinkConfig
impl FileSinkConfig
Sourcepub fn insert_op(&self) -> InsertOp
pub fn insert_op(&self) -> InsertOp
Returns the enum value of insert_op, or the default if the field is set to an invalid enum value.
Sourcepub fn set_insert_op(&mut self, value: InsertOp)
pub fn set_insert_op(&mut self, value: InsertOp)
Sets insert_op to the provided enum value.
Sourcepub fn file_output_mode(&self) -> FileOutputMode
pub fn file_output_mode(&self) -> FileOutputMode
Returns the enum value of file_output_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_file_output_mode(&mut self, value: FileOutputMode)
pub fn set_file_output_mode(&mut self, value: FileOutputMode)
Sets file_output_mode to the provided enum value.