pub struct JsonOptions {
pub compression: i32,
pub schema_infer_max_rec: Option<u64>,
pub compression_level: Option<u32>,
pub newline_delimited: Option<bool>,
}Expand description
Options controlling CSV format
Fields
compression: i32Compression type
schema_infer_max_rec: Option<u64>Optional max records for schema inference
compression_level: Option<u32>Optional compression level
newline_delimited: Option<bool>Whether to read as newline-delimited JSON (default true). When false, expects JSON array format [{},…]
Implementations
Sourceimpl JsonOptions
impl JsonOptions
Sourcepub fn compression(&self) -> CompressionTypeVariant
pub fn compression(&self) -> CompressionTypeVariant
Returns the enum value of compression, or the default if the field is set to an invalid enum value.
Sourcepub fn set_compression(&mut self, value: CompressionTypeVariant)
pub fn set_compression(&mut self, value: CompressionTypeVariant)
Sets compression to the provided enum value.
Sourcepub fn schema_infer_max_rec(&self) -> u64
pub fn schema_infer_max_rec(&self) -> u64
Returns the value of schema_infer_max_rec, or the default value if schema_infer_max_rec is unset.
Sourcepub fn compression_level(&self) -> u32
pub fn compression_level(&self) -> u32
Returns the value of compression_level, or the default value if compression_level is unset.
Sourcepub fn newline_delimited(&self) -> bool
pub fn newline_delimited(&self) -> bool
Returns the value of newline_delimited, or the default value if newline_delimited is unset.