pub struct ParquetCdcOptions {
pub enabled: bool,
pub min_chunk_size: u64,
pub max_chunk_size: u64,
pub norm_level: i32,
}Expand description
Content-defined chunking (CDC) options for writing parquet files.
Fields
enabled: boolmin_chunk_size: u64max_chunk_size: u64norm_level: i32Trait Implementations
Sourceimpl Clone for ParquetCdcOptions
impl Clone for ParquetCdcOptions
Sourcefn clone(&self) -> ParquetCdcOptions
fn clone(&self) -> ParquetCdcOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ParquetCdcOptions
Sourceimpl Debug for ParquetCdcOptions
impl Debug for ParquetCdcOptions
Sourceimpl Default for ParquetCdcOptions
impl Default for ParquetCdcOptions
impl Eq for ParquetCdcOptions
Sourceimpl Hash for ParquetCdcOptions
impl Hash for ParquetCdcOptions
Sourceimpl Message for ParquetCdcOptions
impl Message for ParquetCdcOptions
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ParquetCdcOptions
impl PartialEq for ParquetCdcOptions
Sourcefn eq(&self, other: &ParquetCdcOptions) -> bool
fn eq(&self, other: &ParquetCdcOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ParquetCdcOptions