pub struct PhysicalDynamicFilterNode {
pub children: Vec<PhysicalExprNode>,
pub remapped_children: Vec<PhysicalExprNode>,
pub generation: u64,
pub inner_expr: Option<Box<PhysicalExprNode>>,
pub is_complete: bool,
}Fields
children: Vec<PhysicalExprNode>remapped_children: Vec<PhysicalExprNode>generation: u64inner_expr: Option<Box<PhysicalExprNode>>is_complete: boolTrait Implementations
Sourceimpl Clone for PhysicalDynamicFilterNode
impl Clone for PhysicalDynamicFilterNode
Sourcefn clone(&self) -> PhysicalDynamicFilterNode
fn clone(&self) -> PhysicalDynamicFilterNode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PhysicalDynamicFilterNode
impl Debug for PhysicalDynamicFilterNode
Sourceimpl Default for PhysicalDynamicFilterNode
impl Default for PhysicalDynamicFilterNode
impl<'de> Deserialize<'de> for PhysicalDynamicFilterNode
impl<'de> Deserialize<'de> for PhysicalDynamicFilterNode
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for PhysicalDynamicFilterNode
impl Message for PhysicalDynamicFilterNode
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PhysicalDynamicFilterNode
impl PartialEq for PhysicalDynamicFilterNode
Sourcefn eq(&self, other: &PhysicalDynamicFilterNode) -> bool
fn eq(&self, other: &PhysicalDynamicFilterNode) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for PhysicalDynamicFilterNode
impl Serialize for PhysicalDynamicFilterNode
impl StructuralPartialEq for PhysicalDynamicFilterNode