pub struct PhysicalPlanNode {
pub physical_plan_type: Option<PhysicalPlanType>,
}Expand description
PhysicalPlanNode is a nested type
Fields
physical_plan_type: Option<PhysicalPlanType>Trait Implementations
Sourceimpl AsExecutionPlan for PhysicalPlanNode
impl AsExecutionPlan for PhysicalPlanNode
fn try_decode(buf: &[u8]) -> Result<Self>where
Self: Sized,
fn try_encode<B>(&self, buf: &mut B) -> Result<()>
fn try_into_physical_plan( &self, ctx: &TaskContext, codec: &dyn PhysicalExtensionCodec, ) -> Result<Arc<dyn ExecutionPlan>>
fn try_from_physical_plan(
plan: Arc<dyn ExecutionPlan>,
codec: &dyn PhysicalExtensionCodec,
) -> Result<Self>where
Self: Sized,
Sourceimpl Clone for PhysicalPlanNode
impl Clone for PhysicalPlanNode
Sourcefn clone(&self) -> PhysicalPlanNode
fn clone(&self) -> PhysicalPlanNode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PhysicalPlanNode
impl Debug for PhysicalPlanNode
Sourceimpl Default for PhysicalPlanNode
impl Default for PhysicalPlanNode
Sourcefn default() -> PhysicalPlanNode
fn default() -> PhysicalPlanNode
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PhysicalPlanNode
impl<'de> Deserialize<'de> for PhysicalPlanNode
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<PhysicalPlanNode, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<PhysicalPlanNode, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for PhysicalPlanNode
impl Message for PhysicalPlanNode
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PhysicalPlanNode
impl PartialEq for PhysicalPlanNode
Sourceimpl PhysicalPlanNodeExt for PhysicalPlanNode
impl PhysicalPlanNodeExt for PhysicalPlanNode
Sourcefn node(&self) -> &PhysicalPlanNode
fn node(&self) -> &PhysicalPlanNode
Returns a reference to the underlying
protobuf::PhysicalPlanNode.fn try_into_physical_plan_with_converter( &self, ctx: &TaskContext, codec: &dyn PhysicalExtensionCodec, proto_converter: &dyn PhysicalProtoConverterExtension, ) -> Result<Arc<dyn ExecutionPlan>>
fn try_into_physical_plan_with_context( &self, ctx: &PhysicalPlanDecodeContext<'_>, proto_converter: &dyn PhysicalProtoConverterExtension, ) -> Result<Arc<dyn ExecutionPlan>>
fn try_from_physical_plan_with_converter( plan: Arc<dyn ExecutionPlan>, codec: &dyn PhysicalExtensionCodec, proto_converter: &dyn PhysicalProtoConverterExtension, ) -> Result<PhysicalPlanNode>
fn try_into_extension_physical_plan( &self, extension: &PhysicalExtensionNode, ctx: &PhysicalPlanDecodeContext<'_>, proto_converter: &dyn PhysicalProtoConverterExtension, ) -> Result<Arc<dyn ExecutionPlan>>
fn generate_series_name_to_str(name: GenerateSeriesName) -> &'static str
fn try_into_generate_series_physical_plan( &self, generate_series: &GenerateSeriesNode, ) -> Result<Arc<dyn ExecutionPlan>>
fn str_to_generate_series_name(name: &str) -> Result<GenerateSeriesName>
fn try_from_lazy_memory_exec( exec: &LazyMemoryExec, ) -> Result<Option<PhysicalPlanNode>>
Sourceimpl Serialize for PhysicalPlanNode
impl Serialize for PhysicalPlanNode
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for PhysicalPlanNode