pub struct ScalarSubqueryExecNode {
pub input: Option<Box<PhysicalPlanNode>>,
pub subqueries: Vec<PhysicalPlanNode>,
}Fields
input: Option<Box<PhysicalPlanNode>>subqueries: Vec<PhysicalPlanNode>Trait Implementations
Sourceimpl Clone for ScalarSubqueryExecNode
impl Clone for ScalarSubqueryExecNode
Sourcefn clone(&self) -> ScalarSubqueryExecNode
fn clone(&self) -> ScalarSubqueryExecNode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScalarSubqueryExecNode
impl Debug for ScalarSubqueryExecNode
Sourceimpl Default for ScalarSubqueryExecNode
impl Default for ScalarSubqueryExecNode
impl<'de> Deserialize<'de> for ScalarSubqueryExecNode
impl<'de> Deserialize<'de> for ScalarSubqueryExecNode
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for ScalarSubqueryExecNode
impl Message for ScalarSubqueryExecNode
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ScalarSubqueryExecNode
impl PartialEq for ScalarSubqueryExecNode
Sourcefn eq(&self, other: &ScalarSubqueryExecNode) -> bool
fn eq(&self, other: &ScalarSubqueryExecNode) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for ScalarSubqueryExecNode
impl Serialize for ScalarSubqueryExecNode
impl StructuralPartialEq for ScalarSubqueryExecNode