#[repr(i32)]pub enum MetricCategory {
Rows = 0,
Bytes = 1,
Timing = 2,
Uncategorized = 3,
}Expand description
Category of an EXPLAIN ANALYZE metric. Mirrors
datafusion_common::format::MetricCategory.
Variants
Implementations
Sourceimpl MetricCategory
impl MetricCategory
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<MetricCategory>
pub fn from_str_name(value: &str) -> Option<MetricCategory>
Creates an enum from field names used in the ProtoBuf definition.