pub struct CsvWriterOptions {Show 14 fields
pub compression: i32,
pub delimiter: String,
pub has_header: bool,
pub date_format: String,
pub datetime_format: String,
pub timestamp_format: String,
pub time_format: String,
pub null_value: String,
pub quote: String,
pub escape: String,
pub double_quote: bool,
pub quote_style: i32,
pub ignore_leading_whitespace: bool,
pub ignore_trailing_whitespace: bool,
}Fields
compression: i32Compression type
delimiter: StringOptional column delimiter. Defaults to b','
has_header: boolWhether to write column names as file headers. Defaults to true
date_format: StringOptional date format for date arrays
datetime_format: StringOptional datetime format for datetime arrays
timestamp_format: StringOptional timestamp format for timestamp arrays
time_format: StringOptional time format for time arrays
null_value: StringOptional value to represent null
quote: StringOptional quote. Defaults to b'"'
escape: StringOptional escape. Defaults to '\\'
double_quote: boolOptional flag whether to double quotes, instead of escaping. Defaults to true
quote_style: i32Quote style for CSV writing
ignore_leading_whitespace: boolWhether to ignore leading whitespace in string values
ignore_trailing_whitespace: boolWhether to ignore trailing whitespace in string values
Implementations
Sourceimpl CsvWriterOptions
impl CsvWriterOptions
Sourcepub fn compression(&self) -> CompressionTypeVariant
pub fn compression(&self) -> CompressionTypeVariant
Returns the enum value of compression, or the default if the field is set to an invalid enum value.
Sourcepub fn set_compression(&mut self, value: CompressionTypeVariant)
pub fn set_compression(&mut self, value: CompressionTypeVariant)
Sets compression to the provided enum value.
Sourcepub fn quote_style(&self) -> CsvQuoteStyle
pub fn quote_style(&self) -> CsvQuoteStyle
Returns the enum value of quote_style, or the default if the field is set to an invalid enum value.
Sourcepub fn set_quote_style(&mut self, value: CsvQuoteStyle)
pub fn set_quote_style(&mut self, value: CsvQuoteStyle)
Sets quote_style to the provided enum value.