pub enum PlanTypeEnum {
Show 13 variants
InitialLogicalPlan(EmptyMessage),
AnalyzedLogicalPlan(AnalyzedLogicalPlanType),
FinalAnalyzedLogicalPlan(EmptyMessage),
OptimizedLogicalPlan(OptimizedLogicalPlanType),
FinalLogicalPlan(EmptyMessage),
InitialPhysicalPlan(EmptyMessage),
InitialPhysicalPlanWithStats(EmptyMessage),
InitialPhysicalPlanWithSchema(EmptyMessage),
OptimizedPhysicalPlan(OptimizedPhysicalPlanType),
FinalPhysicalPlan(EmptyMessage),
FinalPhysicalPlanWithStats(EmptyMessage),
FinalPhysicalPlanWithSchema(EmptyMessage),
PhysicalPlanError(EmptyMessage),
}Variants
InitialLogicalPlan(EmptyMessage)
AnalyzedLogicalPlan(AnalyzedLogicalPlanType)
FinalAnalyzedLogicalPlan(EmptyMessage)
OptimizedLogicalPlan(OptimizedLogicalPlanType)
FinalLogicalPlan(EmptyMessage)
InitialPhysicalPlan(EmptyMessage)
InitialPhysicalPlanWithStats(EmptyMessage)
InitialPhysicalPlanWithSchema(EmptyMessage)
OptimizedPhysicalPlan(OptimizedPhysicalPlanType)
FinalPhysicalPlan(EmptyMessage)
FinalPhysicalPlanWithStats(EmptyMessage)
FinalPhysicalPlanWithSchema(EmptyMessage)
PhysicalPlanError(EmptyMessage)
Implementations
Sourceimpl PlanTypeEnum
impl PlanTypeEnum
Sourcepub fn merge(
field: &mut Option<PlanTypeEnum>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<PlanTypeEnum>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.